@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -60,6 +62,13 @@ class AppInfo(AbstractModel):
         self.CreatedTime = params.get("CreatedTime")
         self.BizType = params.get("BizType")
         self.Uin = params.get("Uin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CardInfo(AbstractModel):
@@ -199,6 +208,13 @@ class CardInfo(AbstractModel):
         self.NeedSms = params.get("NeedSms")
         self.Provider = params.get("Provider")
         self.CertificationState = params.get("CertificationState")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CardList(AbstractModel):
@@ -226,6 +242,13 @@ class CardList(AbstractModel):
                 obj = CardInfo()
                 obj._deserialize(item)
                 self.List.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAppRequest(AbstractModel):
@@ -243,6 +266,13 @@ class DescribeAppRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Sdkappid = params.get("Sdkappid")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAppResponse(AbstractModel):
@@ -267,6 +297,13 @@ class DescribeAppResponse(AbstractModel):
             self.Data = AppInfo()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCardRequest(AbstractModel):
@@ -288,6 +325,13 @@ class DescribeCardRequest(AbstractModel):
     def _deserialize(self, params):
         self.Sdkappid = params.get("Sdkappid")
         self.Iccid = params.get("Iccid")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCardResponse(AbstractModel):
@@ -312,6 +356,13 @@ class DescribeCardResponse(AbstractModel):
             self.Data = CardInfo()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCardsRequest(AbstractModel):
@@ -337,6 +388,13 @@ class DescribeCardsRequest(AbstractModel):
         self.Sdkappid = params.get("Sdkappid")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCardsResponse(AbstractModel):
@@ -360,6 +418,69 @@ class DescribeCardsResponse(AbstractModel):
             self.Data = CardList()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class ModifyUserCardRemarkRequest(AbstractModel):
+    """ModifyUserCardRemark请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Sdkappid: 应用ID
+        :type Sdkappid: int
+        :param Iccid: 物联卡ICCID
+        :type Iccid: str
+        :param Remark: 备注信息，限50字
+        :type Remark: str
+        """
+        self.Sdkappid = None
+        self.Iccid = None
+        self.Remark = None
+
+
+    def _deserialize(self, params):
+        self.Sdkappid = params.get("Sdkappid")
+        self.Iccid = params.get("Iccid")
+        self.Remark = params.get("Remark")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class ModifyUserCardRemarkResponse(AbstractModel):
+    """ModifyUserCardRemark返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RenewCardsRequest(AbstractModel):
@@ -385,6 +506,13 @@ class RenewCardsRequest(AbstractModel):
         self.Sdkappid = params.get("Sdkappid")
         self.Iccids = params.get("Iccids")
         self.RenewNum = params.get("RenewNum")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RenewCardsResponse(AbstractModel):
@@ -409,6 +537,13 @@ class RenewCardsResponse(AbstractModel):
             self.Data = ResRenew()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ResRenew(AbstractModel):
@@ -427,6 +562,13 @@ class ResRenew(AbstractModel):
 
     def _deserialize(self, params):
         self.OrderIds = params.get("OrderIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SendMultiSmsRequest(AbstractModel):
@@ -452,6 +594,13 @@ class SendMultiSmsRequest(AbstractModel):
         self.Sdkappid = params.get("Sdkappid")
         self.Iccids = params.get("Iccids")
         self.Content = params.get("Content")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SendMultiSmsResponse(AbstractModel):
@@ -479,6 +628,13 @@ class SendMultiSmsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.Data.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SendSmsRequest(AbstractModel):
@@ -504,6 +660,13 @@ class SendSmsRequest(AbstractModel):
         self.Sdkappid = params.get("Sdkappid")
         self.Iccid = params.get("Iccid")
         self.Content = params.get("Content")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SendSmsResponse(AbstractModel):
@@ -528,6 +691,13 @@ class SendSmsResponse(AbstractModel):
             self.Data = SmsSid()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SmsRet(AbstractModel):
@@ -557,6 +727,13 @@ class SmsRet(AbstractModel):
         self.Msg = params.get("Msg")
         self.Iccid = params.get("Iccid")
         self.Sid = params.get("Sid")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SmsSid(AbstractModel):
@@ -578,4 +755,11 @@ class SmsSid(AbstractModel):
 
     def _deserialize(self, params):
         self.Iccid = params.get("Iccid")
-        self.Sid = params.get("Sid")
\ No newline at end of file
+        self.Sid = params.get("Sid")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
